From 4a93e9b8432661724e9fd400c8f267dd09d3b513 Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter_e@gmx.net>
Date: Wed, 31 May 2017 21:23:06 -0400
Subject: [PATCH] psql: Fix display of whether table is part of publication

If a FOR ALL TABLES publication was present, \d of a table would claim
for each table that it was part of the publication, even for tables that
are ignores, such as system tables and unlogged tables.  Fix the query
by using the function pg_get_publication_tables(), which was intended for
this purpose.

Reported-by: tushar <tushar.ahuja@enterprisedb.com>
---
 src/bin/psql/describe.c | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/src/bin/psql/describe.c b/src/bin/psql/describe.c
index 3e542f7b1d..f1c3d9b7e0 100644
--- a/src/bin/psql/describe.c
+++ b/src/bin/psql/describe.c
@@ -2537,10 +2537,9 @@ describeOneTableDetails(const char *schemaname,
 		{
 			printfPQExpBuffer(&buf,
 							  "SELECT pub.pubname\n"
-							  " FROM pg_catalog.pg_publication pub\n"
-							  " LEFT JOIN pg_catalog.pg_publication_rel pr\n"
-							  "      ON (pr.prpubid = pub.oid)\n"
-							  "WHERE pr.prrelid = '%s' OR pub.puballtables\n"
+							  " FROM pg_catalog.pg_publication pub,\n"
+							  "      pg_catalog.pg_get_publication_tables(pub.pubname)\n"
+							  "WHERE relid = '%s'\n"
 							  "ORDER BY 1;",
 							  oid);
 
-- 
2.13.0

